summaryrefslogtreecommitdiff
path: root/src/leap
diff options
context:
space:
mode:
authorTomás Touceda <chiiph@leap.se>2013-08-08 15:42:51 -0300
committerTomás Touceda <chiiph@leap.se>2013-08-08 15:42:51 -0300
commita6b994f9c201428097676fe914b55d50dfb07db7 (patch)
tree91486ca52fb4e77687cb724bfea4a65263b67830 /src/leap
parente2e6e15fb6546890d39e427b43023bbcc4ceb75f (diff)
parent1f03efa202e4b604b9fb50d0742dc756691e9803 (diff)
Merge remote-tracking branch 'ivan/feature/3313_rebrand-leap-client-to-bitmask' into develop
Diffstat (limited to 'src/leap')
-rw-r--r--src/leap/app.py6
-rw-r--r--src/leap/gui/mainwindow.py24
-rw-r--r--src/leap/gui/ui/loggerwindow.ui2
-rw-r--r--src/leap/gui/ui/mainwindow.ui8
-rw-r--r--src/leap/gui/ui/wizard.ui8
-rw-r--r--src/leap/platform_init/initializers.py6
-rw-r--r--src/leap/services/eip/vpnlaunchers.py4
-rw-r--r--src/leap/services/tx.py2
-rw-r--r--src/leap/util/leap_argparse.py6
9 files changed, 36 insertions, 30 deletions
diff --git a/src/leap/gui/ui/loggerwindow.ui b/src/leap/gui/ui/loggerwindow.ui
index 28325cdf..b08428a9 100644
--- a/src/leap/gui/ui/loggerwindow.ui
+++ b/src/leap/gui/ui/loggerwindow.ui
@@ -15,7 +15,7 @@
</property>
<property name="windowIcon">
<iconset resource="../../../../data/resources/mainwindow.qrc">
- <normaloff>:/images/leap-color-big.png</normaloff>:/images/leap-color-big.png</iconset>
+ <normaloff>:/images/mask-icon.png</normaloff>:/images/mask-icon.png</iconset>
</property>
<layout class="QGridLayout" name="gridLayout">
<item row="2" column="0" colspan="2">
diff --git a/src/leap/gui/ui/mainwindow.ui b/src/leap/gui/ui/mainwindow.ui
index 67d78736..ecd3cbe9 100644
--- a/src/leap/gui/ui/mainwindow.ui
+++ b/src/leap/gui/ui/mainwindow.ui
@@ -11,11 +11,11 @@
</rect>
</property>
<property name="windowTitle">
- <string>LEAP</string>
+ <string>Bitmask</string>
</property>
<property name="windowIcon">
<iconset resource="../../../../data/resources/mainwindow.qrc">
- <normaloff>:/images/leap-color-big.png</normaloff>:/images/leap-color-big.png</iconset>
+ <normaloff>:/images/mask-icon.png</normaloff>:/images/mask-icon.png</iconset>
</property>
<property name="inputMethodHints">
<set>Qt::ImhHiddenText</set>
@@ -166,7 +166,7 @@
<string/>
</property>
<property name="pixmap">
- <pixmap resource="../../../../data/resources/mainwindow.qrc">:/images/leap-color-big.png</pixmap>
+ <pixmap resource="../../../../data/resources/mainwindow.qrc">:/images/mask-launcher.png</pixmap>
</property>
<property name="alignment">
<set>Qt::AlignCenter</set>
@@ -288,7 +288,7 @@
</action>
<action name="action_about_leap">
<property name="text">
- <string>About &amp;LEAP</string>
+ <string>About &amp;Bitmask</string>
</property>
</action>
<action name="action_help">
diff --git a/src/leap/gui/ui/wizard.ui b/src/leap/gui/ui/wizard.ui
index d8acd69a..a8f66bbc 100644
--- a/src/leap/gui/ui/wizard.ui
+++ b/src/leap/gui/ui/wizard.ui
@@ -11,11 +11,11 @@
</rect>
</property>
<property name="windowTitle">
- <string>LEAP First run</string>
+ <string>Bitmask first run</string>
</property>
<property name="windowIcon">
<iconset resource="../../../../data/resources/mainwindow.qrc">
- <normaloff>:/images/leap-color-big.png</normaloff>:/images/leap-color-big.png</iconset>
+ <normaloff>:/images/mask-icon.png</normaloff>:/images/mask-icon.png</iconset>
</property>
<property name="modal">
<bool>true</bool>
@@ -31,7 +31,7 @@
<string>Welcome</string>
</property>
<property name="subTitle">
- <string>This is the LEAP Client first run wizard</string>
+ <string>This is the Bitmask first run wizard</string>
</property>
<attribute name="pageId">
<string notr="true">0</string>
@@ -733,7 +733,7 @@
<string>Congratulations!</string>
</property>
<property name="subTitle">
- <string>You have successfully configured the LEAP Client.</string>
+ <string>You have successfully configured Bitmask.</string>
</property>
<attribute name="pageId">
<string notr="true">6</string>
diff --git a/src/leap/platform_init/initializers.py b/src/leap/platform_init/initializers.py
index cc5f6e87..46488250 100644
--- a/src/leap/platform_init/initializers.py
+++ b/src/leap/platform_init/initializers.py
@@ -84,7 +84,7 @@ def get_missing_updown_dialog():
:rtype: QtGui.QMessageBox instance
"""
WE_NEED_POWERS = ("To better protect your privacy, "
- "LEAP needs administrative privileges "
+ "Bitmask needs administrative privileges "
"to install helper files. "
"Do you want to proceed?")
msg = QtGui.QMessageBox()
@@ -180,7 +180,7 @@ def WindowsInitializer():
if not _windows_has_tap_device():
msg = QtGui.QMessageBox()
msg.setWindowTitle(msg.tr("TAP Driver"))
- msg.setText(msg.tr("LEAPClient needs to install the necessary drivers "
+ msg.setText(msg.tr("Bitmask needs to install the necessary drivers "
"for Encrypted Internet to work. Would you like to "
"proceed?"))
msg.setInformativeText(msg.tr("Encrypted Internet uses VPN, which "
@@ -306,7 +306,7 @@ def DarwinInitializer():
if not _darwin_has_tun_kext():
msg = QtGui.QMessageBox()
msg.setWindowTitle(msg.tr("TUN Driver"))
- msg.setText(msg.tr("LEAPClient needs to install the necessary drivers "
+ msg.setText(msg.tr("Bitmask needs to install the necessary drivers "
"for Encrypted Internet to work. Would you like to "
"proceed?"))
msg.setInformativeText(msg.tr("Encrypted Internet uses VPN, which "
diff --git a/src/leap/services/eip/vpnlaunchers.py b/src/leap/services/eip/vpnlaunchers.py
index cbbd4de2..17950a25 100644
--- a/src/leap/services/eip/vpnlaunchers.py
+++ b/src/leap/services/eip/vpnlaunchers.py
@@ -520,9 +520,9 @@ class DarwinVPNLauncher(VPNLauncher):
COCOASUDO = "cocoasudo"
# XXX need the good old magic translate for these strings
# (look for magic in 0.2.0 release)
- SUDO_MSG = ("LEAP needs administrative privileges to run "
+ SUDO_MSG = ("Bitmask needs administrative privileges to run "
"Encrypted Internet.")
- INSTALL_MSG = ("\"LEAP needs administrative privileges to install "
+ INSTALL_MSG = ("\"Bitmask needs administrative privileges to install "
"missing scripts and fix permissions.\"")
INSTALL_PATH = os.path.realpath(os.getcwd() + "/../../")
diff --git a/src/leap/services/tx.py b/src/leap/services/tx.py
index ef08fcc6..7da1cb01 100644
--- a/src/leap/services/tx.py
+++ b/src/leap/services/tx.py
@@ -40,7 +40,7 @@ def leap_services():
register them.
"""
logger.debug('starting leap services')
- application = Application("LEAP Client Local Services")
+ application = Application("Bitmask Local Services")
#lc = LoopingCall(task)
#lc.start(5)
return application
diff --git a/src/leap/util/leap_argparse.py b/src/leap/util/leap_argparse.py
index bdf80401..f60c4e10 100644
--- a/src/leap/util/leap_argparse.py
+++ b/src/leap/util/leap_argparse.py
@@ -27,9 +27,9 @@ def build_parser():
"""
epilog = "Copyright 2012 The LEAP Encryption Access Project"
parser = argparse.ArgumentParser(description="""
-Launches the LEAP Client""", epilog=epilog)
+Launches Bitmask""", epilog=epilog)
parser.add_argument('-d', '--debug', action="store_true",
- help=("Launches client in debug mode, writing debug"
+ help=("Launches Bitmask in debug mode, writing debug"
"info to stdout"))
# TODO: when we are ready to disable the --danger flag remove 'True or '
if True or not IS_RELEASE_VERSION:
@@ -45,7 +45,7 @@ Launches the LEAP Client""", epilog=epilog)
action="store", dest="openvpn_verb",
help='verbosity level for openvpn logs [1-6]')
parser.add_argument('-s', '--standalone', action="store_true",
- help='Makes the client use standalone'
+ help='Makes Bitmask use standalone'
'directories for configuration and binary'
'searching')
diff --git a/src/leap/app.py b/src/leap/app.py
index e7a8aa42..22340d4d 100644
--- a/src/leap/app.py
+++ b/src/leap/app.py
@@ -148,16 +148,16 @@ def main():
replace_stdout_stderr_with_logging(logger)
if not we_are_the_one_and_only():
# leap-client is already running
logger.warning("Tried to launch more than one instance "
- "of leap-client. Raising the existing "
+ "of Bitmask. Raising the existing "
"one instead.")
sys.exit(1)
check_requirements()
logger.info('~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~')
- logger.info('LEAP client version %s', VERSION)
+ logger.info('Bitmask version %s', VERSION)
logger.info('~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~')
logger.info('Starting app')
@@ -148,16 +148,16 @@ def main():
replace_stdout_stderr_with_logging(logger)
if not we_are_the_one_and_only():
- # leap-client is already running
+ # Bitmask is already running
logger.warning("Tried to launch more than one instance "
diff --git a/src/leap/gui/mainwindow.py b/src/leap/gui/mainwindow.py
index 5c7a3928..90492e45 100644
--- a/src/leap/gui/mainwindow.py
+++ b/src/leap/gui/mainwindow.py
@@ -83,7 +83,7 @@ class MainWindow(QtGui.QMainWindow):
EIP_STATUS_INDEX = 1
# Keyring
- KEYRING_KEY = "leap_client"
+ KEYRING_KEY = "bitmask"
# SMTP
PORT_KEY = "port"
@@ -423,11 +423,11 @@ class MainWindow(QtGui.QMainWindow):
Parses and displays the updates details
"""
- msg = self.tr("The LEAPClient app is ready to update, please"
+ msg = self.tr("The Bitmask app is ready to update, please"
" restart the application.")
# We assume that if there is nothing in the contents, then
# the LEAPClient bundle is what needs updating.
if len(self._updates_content) > 0:
files = self._updates_content.split(", ")
files_str = ""
@@ -655,17 +655,23 @@ class MainWindow(QtGui.QMainWindow):
SLOT
TRIGGERS: self.ui.action_about_leap.triggered
Display the About LEAP dialog
"""
QtGui.QMessageBox.about(
- self, self.tr("About LEAP - %s") % (VERSION,),
- self.tr("version: <b>%s</b><br>"
+ self, self.tr("About Bitmask - %s") % (VERSION,),
+ self.tr("Version: <b>%s</b><br>"
+ "<br>"
+ "Bitmask is the Desktop client application for "
+ "the LEAP platform, supporting encrypted internet "
+ "proxy, secure email, and secure chat (coming soon).<br>"
+ "<br>"
"LEAP is a non-profit dedicated to giving "
"all internet users access to secure "
"communication. Our focus is on adapting "
"encryption technology to make it easy to use "
- "and widely available. "
- "<a href=\"https://leap.se\">More about LEAP"
+ "and widely available. <br>"
+ "<br>"
+ "<a href='https://leap.se'>More about LEAP"
"</a>") % (VERSION,))
def changeEvent(self, e):
@@ -1145,7 +1151,7 @@ class MainWindow(QtGui.QMainWindow):
self._status_panel.set_global_status(
self.tr("Another openvpn instance is already running, and "
"could not be stopped because it was not launched by "
- "LEAP. Please stop it and try again."),
+ "Bitmask. Please stop it and try again."),
error=True)
self._set_eipstatus_off()
except VPNLauncherException as e:
@@ -423,11 +423,11 @@ class MainWindow(QtGui.QMainWindow):
" restart the application.")
# We assume that if there is nothing in the contents, then
- # the LEAPClient bundle is what needs updating.
+ # the Bitmask bundle is what needs updating.
if len(self._updates_content) > 0:
files = self._updates_content.split(", ")
@@ -655,17 +655,23 @@ class MainWindow(QtGui.QMainWindow):
SLOT
TRIGGERS: self.ui.action_about_leap.triggered
- Display the About LEAP dialog
+ Display the About Bitmask dialog
"""
QtGui.QMessageBox.about(